/**
  Getting Started with RS-485 on Opta™
  Name: Opta_RS485_Sender
  Purpose: Sends values to Receiver Opta via Serial Monitor

  @author Giampaolo Mancini, Arduino
  @version 1.0 02/02/2023 
*/

#include <ArduinoRS485.h>

constexpr auto baudrate{ 115200 };

// Calculate preDelay and postDelay in microseconds for stable RS-485 transmission
constexpr auto bitduration{ 1.f / baudrate };
constexpr auto wordlen{ 9.6f };  // OR 10.0f depending on the channel configuration
constexpr auto preDelayBR{ bitduration * wordlen * 3.5f * 1e6 };
constexpr auto postDelayBR{ bitduration * wordlen * 3.5f * 1e6 };

void setup() {
  Serial.begin(baudrate);
  while (!Serial);
  
  RS485.begin(baudrate);
  RS485.setDelays(preDelayBR, postDelayBR);
}

void loop() {

  auto aval = Serial.available();
  if (aval > 0) {
    auto input = Serial.readStringUntil('\r');

    // Discard EOL
    auto read = input.length();
    while (aval > ++read)
      Serial.read();

    auto incomingByte = input.toInt();
    RS485.beginTransmission();
    Serial.print("- Sending: ");
    Serial.println(incomingByte);
    RS485.write(incomingByte);
    RS485.endTransmission();
  }
}